@@ -1574,7 +1574,7 @@ class NcmClient:
         :param group_id: ID of destination group.
         :return:
         """
-        call_type = "Routers"
+        call_type = "Router"
 
         put_url = '{0}/routers/{1}/'.format(self.base_url, str(router_id))
 
@@ -1587,6 +1587,34 @@ class NcmClient:
         result = self.__return_handler(ncm.status_code, ncm.json(), call_type)
         return result
 
+    def remove_router_from_group(self, router_id=None, router_name=None):
+        """
+        This operation removes a router from its group.
+        Either the ID or the name must be specified.
+        :param router_id: ID of router to move.
+        :param router_name: Name of router to move
+        :return:
+        """
+        call_type = "Router"
+        if not router_id and not router_name:
+            return "ERROR: Either Router ID or Router Name must be specified."
+        if not router_id:
+            router_id = self.get_router_by_name(router_name)['id']
+
+        put_url = '{0}/routers/{1}/'.format(self.base_url, str(router_id))
+
+        put_data = {
+            "group": None
+        }
+
+        ncm = self.session.put(put_url, data=json.dumps(put_data))
+        if ncm.status_code == 201 or ncm.status_code == 202:
+            if self.logEvents:
+                print('Router Modified Successfully\n')
+            return None
+        result = self.__return_handler(ncm.status_code, ncm.json(), call_type)
+        return result
+
     def assign_router_to_account(self, router_id, account_id):
         """
         This operation assigns a router to an account.
@@ -1703,7 +1731,6 @@ class NcmClient:
 
         net_devices = self.get_net_devices_for_router(router_id, connection_state='connected', is_asset=True)
         net_device_ids = [int(x["id"]) for x in net_devices]
-        print(net_device_ids)
         speed_test = self.create_speed_test(net_device_ids=net_device_ids,
                                             account_id=account_id,
                                             host=host,
